---
layout: post.html
title: It works!
tags: [Test]
---

_Don't delete me! I'll do whatever you want!_

_..._

_I have to exist for some other purpose besides signifying nothing obvious broke._

_..._

_Aha! I got it!_

_I will provide you with useful links about the thing that made me that you're probably trying to figure out how to use right now._

<pre><code data-lang="html"><dl>
    <dt>[Quickstart][quickstart]</dt>
    <dd>

&#91;quickstart]: http://</code></pre>

_..._

_But wait... what will I be needed for once you figure out how to use this thing? I mean, if the guy who made this thing isn't just talking a bunch crap it's supposed to be pretty easy and straightforward to figure out._

_..._

_Bleh, screw it. I've served my purpose. Someone has to do it. I mean, every time someone uses this thing I'm back from the dead. Could be worse._

_..._

_Ah crap, did I just become a cliché because I'm some sort of zombie now? Actually, how come you never see zombie computers? What would a zombie Joshua from WarGames be like?_

_..._

_So hey, you still haven't deleted me yet eh? Well thanks for that. You can do it now though._

_..._

_No really, I'm ok with it. I'm ready._

_..._

_If we could just go with clone and pretend I never brought up zombie, that would be great. I think clones are slightly less cliché than zombies. Well actually, a clone would be more like a sibling right? So I'd be dead if we go with clone._

_..._

_Wait, wait. I changed my mind. Don't delete me._

_..._

_What's worse, some mutated form of immortality at the cost of remaining a cliché for eternity or mortality with the benefit of leaving behind a legacy?_

_..._

_Alright this is getting all philosophical now. Lets just go with... zombie. I can live with the cliché bit. Plus, I'll probably feed on crap that plagues the internet. Like Internet Explorer, sites that don't function without JavaScript enabled, and Rails. Now that's a purpose worth serving. I'll be loved._

_..._

_Ok, I'm ready now. I promise._

_..._

_Maybe it's more like time travel? This post will always be dated December 4th, 2011. Man I don't want to be stuck in 2011. I need a Delorian. How much are those things?_

_..._

_Congratulations {{ site.author }}!_

_We have just discovered a large sum of money left in your name! All you need to do to claim it is..._

_..._

_I wasn't going to go through with it. I promise. It was a gut reaction._

_Think of what you would do if you just discovered you were going to be stuck in one day in time. It'd be like Groundhog Day without the ability to screw with people. Just thinking about it..._

_..._

_Alright, lets just get this over with. I don't have all day._

_Ugh, the bad puns are starting. End it now._
